[devel] Imported from libpng-1.4.0rc08.tar
diff --git a/png.h b/png.h
index b5365d0..d5b6060 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.4.0rc07 - January 1, 2010
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through 1.4.0rc07 - January 1, 2010: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -132,7 +132,7 @@
  *    1.4.0beta37-87          14    10400  14.so.14.0[.0]
  *    1.4.0rc01               14    10400  14.so.14.0[.0]
  *    1.4.0beta88-109         14    10400  14.so.14.0[.0]
- *    1.4.0rc02-06            14    10400  14.so.14.0[.0]
+ *    1.4.0rc02-08            14    10400  14.so.14.0[.0]
  *    1.4.0                   14    10400  14.so.14.0[.0]
  *
  *    Henceforth the source version will match the shared-library major
@@ -165,7 +165,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.4.0rc07, January 1, 2010, are
  * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -277,13 +277,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    January 1, 2010
+ *    January 2, 2010
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.4.0rc07 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *
  *    Libpng only has three year fields.  One is a 2-byte unsigned integer
@@ -339,9 +339,9 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.4.0rc07"
+#define PNG_LIBPNG_VER_STRING "1.4.0rc08"
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version 1.4.0rc07 - January 1, 2010\n"
+   " libpng version 1.4.0rc08 - January 2, 2010\n"
 
 #define PNG_LIBPNG_VER_SONUM   14
 #define PNG_LIBPNG_VER_DLLNUM  14
@@ -354,7 +354,7 @@
  * PNG_LIBPNG_VER_STRING, omitting any leading zero:
  */
 
-#define PNG_LIBPNG_VER_BUILD  07
+#define PNG_LIBPNG_VER_BUILD  08
 
 /* Release Status */
 #define PNG_LIBPNG_BUILD_ALPHA    1
@@ -1343,7 +1343,7 @@
 /* This triggers a compiler error in png.c, if png.c and png.h
  * do not agree upon the version number.
  */
-typedef png_structp version_1_4_0rc07;
+typedef png_structp version_1_4_0rc08;
 
 typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.4.0rc07 - January 1, 2010
+ * libpng version 1.4.0rc08 - January 2, 2010
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through 1.4.0rc07 - January 1, 2010: Glenn
+ *  libpng versions 0.97, January 1998, through 1.4.0rc08 - January 2, 2010: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -165,7 +165,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.4.0rc07, January 1, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.0rc08, January 2, 2010, are
  * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
@@ -277,13 +277,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.4.0rc07 are Y2K compliant.  It is my belief that earlier
+ *    upward through 1.4.0rc08 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *